@@ -41,7 +41,7 @@ class App:
             server_name=socket.gethostname()
         )
         
-        self._create_defaults()
+        # self._create_defaults()
 
     def wsgi_app(self, environ, start_response):
         request = Request(environ)
@@ -129,10 +129,10 @@ class App:
             loader=FileSystemLoader(os.path.abspath(templates_dir)))
         self.templates_dir = templates_dir
     
-    def create_defaults(self):
-        os.mkdir("apppages")
-        with open(f'{os.path.abspath("apppages")}/error404.html', "w") as f:
-            f.write("...")
+    # def create_defaults(self):
+    #     os.mkdir("apppages")
+    #     with open(f'{os.path.abspath("apppages")}/error404.html', "w") as f:
+    #         f.write("...")
             
 
     def run(self):
